7030174: Jarsigner should accept TSACert with an HTTPS id-ad-timeStamping SIA
authorweijun
Thu, 24 Mar 2011 16:16:22 +0800
changeset 8998 96d4e9ea2423
parent 8997 21fb23e5ec42
child 8999 ceee82509f6b
7030174: Jarsigner should accept TSACert with an HTTPS id-ad-timeStamping SIA Reviewed-by: xuelei
jdk/src/share/classes/sun/security/tools/TimestampedSigner.java
--- a/jdk/src/share/classes/sun/security/tools/TimestampedSigner.java	Wed Mar 23 20:25:43 2011 -0700
+++ b/jdk/src/share/classes/sun/security/tools/TimestampedSigner.java	Thu Mar 24 16:16:22 2011 +0800
@@ -250,10 +250,10 @@
      * (<a href="http://www.ietf.org/rfc/rfc3280.txt">RFC 3280</a>).
      * The extension's <tt>accessMethod</tt> field should contain the object
      * identifier defined for timestamping: 1.3.6.1.5.5.7.48.3 and its
      * <tt>accessLocation</tt> field should contain an HTTP URL.
      *
      * @param tsaCertificate An X.509 certificate for the TSA.
      * @return An HTTP URL or null if none was found.
      */
     public static String getTimestampingUrl(X509Certificate tsaCertificate) {
 
@@ -279,7 +279,8 @@
                     location = description.getAccessLocation();
                     if (location.getType() == GeneralNameInterface.NAME_URI) {
                         uri = (URIName) location.getName();
-                        if (uri.getScheme().equalsIgnoreCase("http")) {
+                        if (uri.getScheme().equalsIgnoreCase("http") ||
+                                uri.getScheme().equalsIgnoreCase("https")) {
                             return uri.getName();
                         }
                     }
@@ -250,10 +250,10 @@
      * The extension's <tt>accessMethod</tt> field should contain the object
      * identifier defined for timestamping: 1.3.6.1.5.5.7.48.3 and its
-     * <tt>accessLocation</tt> field should contain an HTTP URL.
+     * <tt>accessLocation</tt> field should contain an HTTP or HTTPS URL.
      *
      * @param tsaCertificate An X.509 certificate for the TSA.
@@ -250,10 +250,10 @@
      *
      * @param tsaCertificate An X.509 certificate for the TSA.
-     * @return An HTTP URL or null if none was found.
+     * @return An HTTP or HTTPS URL or null if none was found.
      */
     public static String getTimestampingUrl(X509Certificate tsaCertificate) {